@@ -58,7 +58,7 @@ class Vocabulary(object):
     """
 
     def __init__(self, data, lang: str="Es", 
-                 country: str=None, states: bool=False) -> None:
+                 country: str='nogeo', states: bool=False) -> None:
         self._lang = lang
         self._country = country
         self._states = states
@@ -240,8 +240,10 @@ class Vocabulary(object):
         from .dataset import Dataset
         data = Dataset()
         data.add(data.load_emojis())
-        keys = [(k, [x for x in data.klass(k) if not x.isnumeric()])  for k in self]
-        keys = [(k, v) for k, v in keys if len(v) and v[0] != "#"]
+        # keys = [(k, [x for x in data.klass(k) if not x.isnumeric()])  for k in self]
+        keys = [(k, [x for x in data.klass(k)]) for k in self]
+        # keys = [(k, v) for k, v in keys if len(v) and v[0] != "#"]
+        keys = [(k, v) for k, v in keys if len(v)]        
         for k, v in keys:
             del self.voc[k]
 
@@ -330,7 +332,7 @@ class Vocabulary(object):
         :lang lang: Language
         """
 
-        missing = Counter(countries) if countries is not None else None
+        missing = Counter(countries) if countries is not 'nogeo' else None
         rest = []
         dates = dates[::-1]
         while len(dates) and (len(rest) < n or n == -1):
@@ -339,7 +341,8 @@ class Vocabulary(object):
           iter = missing.most_common() if missing is not None else [[None, None]]
           for country, _ in iter:
             try:
-                download_tokens(day, lang=lang, country=country)
+                download_tokens(day, lang=lang, 
+                                country=country if country is not None else 'nogeo')
             except Exception:
               flag = False
               if missing is not None:
@@ -570,7 +573,9 @@ class TopicDetection(object):
     :type country: str
     """
 
-    def __init__(self, date, lang: str="En", country: str="US"):
+    def __init__(self, date, lang: str="En", country: str="US",
+                 window: int=2):
+        self._window = window
         self.date = handle_day(date)
         self._lang = lang
         self._country = country
@@ -578,6 +583,10 @@ class TopicDetection(object):
         self._prev_date = self.similar_date()
         self._prev_voc = Vocabulary(self._prev_date, lang=self._lang, country=self._country)
 
+    @property
+    def window(self):
+        return self._window
+
     @property
     def prev_date(self):
         return self._prev_date
@@ -610,7 +619,8 @@ class TopicDetection(object):
 
         # Get vocabulary of previous dates
         prev_voc = []
-        prev_days = date_range(date - timedelta(days=7), date + timedelta(days=8))
+        w = self.window
+        prev_days = date_range(date - timedelta(days=w), date + timedelta(days=w + 1))
         for day in prev_days:
             _ = dict(year=day.year - 1, month=day.month, day=day.day)
             prev_voc.append(Vocabulary(_, lang=self._lang, country=self._country))
